//
//  DetailViewController.swift
//  notes - demo project for TMA 2018
//
//  Created by Ondřej Hanák on 28. 11. 2018.
//  Copyright © 2018 Ondrej Hanak. All rights reserved.
//

import UIKit

protocol DetailDelegate: class {
	func noteDidChange(_ note: Note)
}

final class DetailViewController: UIViewController, UITextViewDelegate {
	
	@IBOutlet var textView: UITextView!
	weak var delegate: DetailDelegate?
	var note: Note?
	var changed = false
	var backButton: UIBarButtonItem!
	var saveButton: UIBarButtonItem!
	var cancelButton: UIBarButtonItem!
	
	// MARK: - Lifecycle
	
	override func viewDidLoad() {
		super.viewDidLoad()
		self.backButton = self.navigationItem.backBarButtonItem
		self.cancelButton = UIBarButtonItem(title: "Cancel", style: .plain, target: self, action: #selector(cancelTapped(_:)))
		self.saveButton = UIBarButtonItem(title: "Save", style: .done, target: self, action: #selector(saveTapped(_:)))
		self.loadData()
	}
	
	// MARK: - UITextViewDelegate
	
	func textViewDidChange(_ textView: UITextView) {
		self.textChanged()
	}
	
	// MARK: - Private
	
	func loadData() {
		if let note = self.note {
			self.title = note.modifiedDescription
		} else {
			self.title = "New Note"
		}
		self.textView.text = self.note?.text
	}
	
	@objc func saveTapped(_ sender: UIBarButtonItem) {
		if let existingNote = self.note {
			existingNote.text = self.textView.text
			self.delegate?.noteDidChange(existingNote)
		} else {
			let newNote = Note(text: self.textView.text)
			self.delegate?.noteDidChange(newNote)
		}
		self.navigationController?.popViewController(animated: true)
	}
	
	@objc func cancelTapped(_ sender: UIBarButtonItem) {
		self.loadData()
		self.changed = false
		self.navigationItem.leftBarButtonItem = self.backButton
		self.navigationItem.rightBarButtonItem = nil
	}
	
	func textChanged() {
		guard !self.changed else { return }
		self.changed = true
		self.navigationItem.leftBarButtonItem = self.cancelButton
		self.navigationItem.rightBarButtonItem = self.saveButton
	}
	
}
