//
//  ListViewController.swift
//  notes - demo project for TMA 2018
//
//  Created by Ondřej Hanák on 28. 11. 2018.
//  Copyright © 2018 Ondrej Hanak. All rights reserved.
//

import UIKit

private let detailSegue = "showDetail"
private let noteCell = "noteCell"

final class ListViewController: UIViewController, UITableViewDelegate, UITableViewDataSource, DetailDelegate {
	
	@IBOutlet var tableView: UITableView!
	let storage = NotesStorage()
	// MARK: - Lifecycle
	
	override func viewDidLoad() {
		super.viewDidLoad()
		self.tableView.delegate = self
		self.tableView.dataSource = self
	}
	
	override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
		if segue.identifier == detailSegue {
			if let vc = segue.destination as? DetailViewController {
				vc.note = sender as? Note
				vc.delegate = self
			}
		}
	}
	
	@IBAction func addTapped(_ sender: UIBarButtonItem) {
		self.performSegue(withIdentifier: detailSegue, sender: nil)
	}
	
	// MARK: - UITableViewDataSource
	
	func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
		return self.storage.notes.count
	}
	
	func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
		let cell = tableView.dequeueReusableCell(withIdentifier: noteCell, for: indexPath)
		let note = self.storage.notes[indexPath.row]
		cell.textLabel?.text = note.text
		cell.detailTextLabel?.text = note.modifiedDescription
		return cell
	}
	
	func tableView(_ tableView: UITableView, canEditRowAt indexPath: IndexPath) -> Bool {
		return true
	}
	
	func tableView(_ tableView: UITableView, commit editingStyle: UITableViewCell.EditingStyle, forRowAt indexPath: IndexPath) {
		if editingStyle == .delete {
			let note = self.storage.notes[indexPath.row]
			self.storage.delete(note)
			tableView.deleteRows(at: [indexPath], with: .automatic)
		}
	}
	
	// MARK: - UITableViewDelegate
	
	func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
		let note = self.storage.notes[indexPath.row]
		self.performSegue(withIdentifier: detailSegue, sender: note)
		tableView.deselectRow(at: indexPath, animated: true)
	}
	
	// MARK: - DetailDelegate
	
	func noteDidChange(_ note: Note) {
		self.storage.save(note)
		self.tableView.reloadData()
	}
	
}
