//
//  notes - demo project for TMA 2018Storage.swift
//  notes - demo project for TMA 2018
//
//  Created by Ondřej Hanák on 28. 11. 2018.
//  Copyright © 2018 Ondrej Hanak. All rights reserved.
//

import Foundation

final class NotesStorage {
	
	private(set) var notes: [Note] = []
	private let fileManager = FileManager.default
	private let fileName = "notes.json"
	
	// MARK: - Lifecycle
	
	init() {
		self.load()
	}
	
	// MARK: - Public
	
	func save(_ note: Note) {
		if let index = self.notes.lastIndex(of: note) {
			self.notes[index] = note
		} else {
			self.notes.append(note)
		}
		self.persist()
	}
	
	func delete(_ note: Note) {
		guard let index = self.notes.firstIndex(of: note) else { return }
		self.notes.remove(at: index)
		self.persist()
	}
	
	// MARK: - Private
	
	private func persist() {
		let data = try! JSONEncoder().encode(self.notes)
		try! data.write(to: self.fileURL)
	}
	
	private func load() {
		do {
			let data = try Data(contentsOf: self.fileURL)
			self.notes = try JSONDecoder().decode([Note].self, from: data)
		} catch {
			self.notes = []
		}
	}
	
	lazy var fileURL: URL = {
		let documentDirectory = try! fileManager.url(for: .documentDirectory, in: .userDomainMask, appropriateFor:nil, create:false)
		let url = documentDirectory.appendingPathComponent(fileName)
		return url
	}()
	
}
